! ############################################################
!            Satellite Data Simulation Unit v2
!                     - open_lut_vir -
!
! This subroutine reads the Mie lookup tables created by the
! program stored in "src/MieLUT". Any changes made to the LUT
! format must be reflected in this subroutine. Make sure
! that the specified file names match existing LUTs. The path
! to LUTs is given by "lutdir" defined in 'MAINparameters'.
!
!                              Created by H. M. (May, 2009)
!                Updated for SDSU v.2.1.0 by H. M. (Aug, 2009)
!
 Subroutine open_lut_vir ( iw )
   Use MAINparameters
   Use VIRparameters
   Use MCRPparameters
   Implicit NONE
!
! I/O parameters
!
   integer, intent(in) :: iw
!
! Local variables
!
   real :: wavelngth
   Integer :: i,j,k,m
   Character*4  :: nch, mklab_lut_vir
   Character*50 :: fname_in
   Character*100 :: pathandfile
! 
! "nch" is automatically assigned by "mklab_lut"
!
   nch = mklab_lut_vir ( wavel(iw) )
!
! Cloud Ice
!
   fname_in = cldi%functype//'/'//trim(cldi%name)//'-vir'//nch//'.dat'
   pathandfile = lutdir//fname_in
   Open ( Unit=50, File=pathandfile )
!
   read(50,*) npts_temp, npts_hydro, npts_ncnc
!
   allocate ( cextci_lut(npts_hydro,npts_temp,npts_ncnc) )
   allocate ( cscaci_lut(npts_hydro,npts_temp,npts_ncnc) )
   allocate ( phsfci_lut(knang,npts_hydro,npts_temp,npts_ncnc) )
   allocate ( ptn_cldi(npts_ncnc), pts_hydro(npts_hydro) )
   allocate ( pts_temp_i(npts_temp), pts_temp_w(npts_temp) )
!
   read(50,*) (pts_temp_i(i),i=1,npts_temp)
   read(50,*) (pts_hydro(i),i=1,npts_hydro)
   read(50,*) (ptn_cldi(i) ,i=1,npts_ncnc )
   read(50,*) wavelngth
!
   read(50,*) (((cextci_lut(i,j,k),cscaci_lut(i,j,k),(phsfci_lut(m,i,j,k), &
                m=1,nang),i = 1,npts_hydro),j=1,npts_temp),k=1,npts_ncnc)
   close (50)
!
! Cloud Water
!
   fname_in = cldw%functype//'/'//trim(cldw%name)//'-vir'//nch//'.dat'
   pathandfile = lutdir//fname_in
   Open ( Unit=50, File=pathandfile )
!
   read(50,*)  npts_temp, npts_hydro, npts_ncnc
!
   allocate ( cextcw_lut(npts_hydro,npts_temp,npts_ncnc) )
   allocate ( cscacw_lut(npts_hydro,npts_temp,npts_ncnc) )
   allocate ( phsfcw_lut(knang,npts_hydro,npts_temp,npts_ncnc) )
   allocate ( ptn_cldw(npts_ncnc) )
!
   read(50,*) (pts_temp_w(i),i=1,npts_temp)
   read(50,*) (pts_hydro(i),i=1,npts_hydro)
   read(50,*) (ptn_cldw(i) ,i=1,npts_ncnc )
   read(50,*) wavelngth
!
   read(50,*) (((cextcw_lut(i,j,k),cscacw_lut(i,j,k),(phsfcw_lut(m,i,j,k), &
                m=1,nang),i = 1,npts_hydro),j=1,npts_temp),k=1,npts_ncnc)
   close (50)
!
! Rain
!
   fname_in = rain%functype//'/'//trim(rain%name)//'-vir'//nch//'.dat'
   pathandfile = lutdir//fname_in
   Open ( Unit=50, File=pathandfile )
!
   read(50,*)  npts_temp, npts_hydro, npts_ncnc
!
   allocate ( cextrr_lut(npts_hydro,npts_temp,npts_ncnc) )
   allocate ( cscarr_lut(npts_hydro,npts_temp,npts_ncnc) )
   allocate ( phsfrr_lut(knang,npts_hydro,npts_temp,npts_ncnc) )
   allocate ( ptn_rain(npts_ncnc) )
!
   read(50,*) (pts_temp_w(i),i=1,npts_temp)
   read(50,*) (pts_hydro(i),i=1,npts_hydro)
   read(50,*) (ptn_rain(i) ,i=1,npts_ncnc )
   read(50,*) wavelngth
!
   read(50,*) (((cextrr_lut(i,j,k),cscarr_lut(i,j,k),(phsfrr_lut(m,i,j,k), &
                m=1,nang),i = 1,npts_hydro),j=1,npts_temp),k=1,npts_ncnc)
   close (50)
!
! Snow
!
   fname_in = snow%functype//'/'//trim(snow%name)//'-vir'//nch//'.dat'
   pathandfile = lutdir//fname_in
   Open ( Unit=50, File=pathandfile )
!
   read(50,*)  npts_temp, npts_hydro, npts_ncnc
!
   allocate ( cextsn_lut(npts_hydro,npts_temp,npts_ncnc) )
   allocate ( cscasn_lut(npts_hydro,npts_temp,npts_ncnc) )
   allocate ( phsfsn_lut(knang,npts_hydro,npts_temp,npts_ncnc) )
   allocate ( ptn_snow(npts_ncnc) )
!
   read(50,*) (pts_temp_i(i),i=1,npts_temp)
   read(50,*) (pts_hydro(i),i=1,npts_hydro)
   read(50,*) (ptn_snow(i) ,i=1,npts_ncnc )
   read(50,*) wavelngth
!
   read(50,*) (((cextsn_lut(i,j,k),cscasn_lut(i,j,k),(phsfsn_lut(m,i,j,k), &
                m=1,nang),i = 1,npts_hydro),j=1,npts_temp),k=1,npts_ncnc)
   close (50)
!
! Graupel
!
   fname_in = grpl%functype//'/'//trim(grpl%name)//'-vir'//nch//'.dat'
   pathandfile = lutdir//fname_in
   Open ( Unit=50, File=pathandfile )
!
   read(50,*)  npts_temp, npts_hydro, npts_ncnc
!
   allocate ( cextgr_lut(npts_hydro,npts_temp,npts_ncnc) )
   allocate ( cscagr_lut(npts_hydro,npts_temp,npts_ncnc) )
   allocate ( phsfgr_lut(knang,npts_hydro,npts_temp,npts_ncnc) )
   allocate ( ptn_grpl(npts_ncnc) )
!
   read(50,*) (pts_temp_i(i),i=1,npts_temp)
   read(50,*) (pts_hydro(i),i=1,npts_hydro)
   read(50,*) (ptn_grpl(i) ,i=1,npts_ncnc )
   read(50,*) wavelngth
!
   read(50,*) (((cextgr_lut(i,j,k),cscagr_lut(i,j,k),(phsfgr_lut(m,i,j,k), &
                m=1,nang),i = 1,npts_hydro),j=1,npts_temp),k=1,npts_ncnc)
   close (50)
!
! Hail
!
   fname_in = hail%functype//'/'//trim(hail%name)//'-vir'//nch//'.dat'
   pathandfile = lutdir//fname_in
   Open ( Unit=50, File=pathandfile )
!
   read(50,*)  npts_temp, npts_hydro, npts_ncnc
!
   allocate ( cexthl_lut(npts_hydro,npts_temp,npts_ncnc) )
   allocate ( cscahl_lut(npts_hydro,npts_temp,npts_ncnc) )
   allocate ( phsfhl_lut(knang,npts_hydro,npts_temp,npts_ncnc) )
   allocate ( ptn_hail(npts_ncnc) )
!
   read(50,*) (pts_temp_i(i),i=1,npts_temp)
   read(50,*) (pts_hydro(i),i=1,npts_hydro)
   read(50,*) (ptn_hail(i) ,i=1,npts_ncnc )
   read(50,*) wavelngth
!
   read(50,*) (((cexthl_lut(i,j,k),cscahl_lut(i,j,k),(phsfhl_lut(m,i,j,k), &
                m=1,nang),i = 1,npts_hydro),j=1,npts_temp),k=1,npts_ncnc)
   close (50)
!
   Return
 End Subroutine open_lut_vir

